@@ -16,8 +16,8 @@ use crate::protocol::{
 use crate::types::*;
 
 // Trick to have common implementation for std and mio streams..
-#[cfg(not(feature = "async-mio"))]
-pub(crate) use std::fmt::Debug as Source;
+#[cfg(all(not(feature = "async-mio"), unix))]
+pub(crate) use std::os::unix::io::AsRawFd as Source;
 
 #[cfg(feature = "async-mio")]
 pub(crate) use mio::event::Source;
@@ -179,6 +179,18 @@ impl<S: Read + Write + Source> Client<S> {
         Self { input, output }
     }
 
+    #[cfg(all(not(feature = "async-mio"), unix))]
+    /// Input source for asynchronous API based on `poll`.
+    pub(crate) fn input_source(&self) -> &S {
+        self.input.get_ref()
+    }
+
+    #[cfg(all(not(feature = "async-mio"), unix))]
+    /// Output source for asynchronous API based on `poll`.
+    pub(crate) fn output_source(&self) -> &S {
+        self.output.get_ref()
+    }
+
     /// Send lines of text (terminated by a single dot).
     pub fn send_lines(&mut self, lines: &[String]) -> ClientResult<&mut Self> {
         const END_OF_DATA: [&str; 1] = ["."];
